@@ -19,6 +19,12 @@
 #' @param surv_time scalar. Survival time of interest for computing the
 #'   probability of survival for a single arm (OPC) trial. Default is
 #'   overall, i.e., current+historical, median survival time.
+#' @param discount_function character. Specify the discount function to use.
+#'   Currently supports \code{weibull}, \code{scaledweibull}, and
+#'   \code{identity}. The discount function \code{scaledweibull} scales
+#'   the output of the Weibull CDF to have a max value of 1. The \code{identity}
+#'   discount function uses the posterior probability directly as the discount
+#'   weight. Default value is "\code{weibull}".
 #' @param alpha_max scalar. Maximum weight the discount function can apply.
 #'   Default is 1. For a two-arm trial, users may specify a vector of two values
 #'   where the first value is used to weight the historical treatment group and
@@ -37,13 +43,18 @@
 #'   values where the first value is used to estimate the weight of the
 #'   historical treatment group and the second value is used to estimate the
 #'   weight of the historical control group.
-#' @param two_side logical. Indicator of two-sided test for the discount
-#'   function. Default value is TRUE.
 #' @param method character. Analysis method with respect to estimation of the weight
 #'   paramter alpha. Default value "\code{fixed}" estimates alpha once and holds it fixed
 #'   throughout the analysis. Alternative method "\code{mc}" estimates alpha for each
 #'   Monte Carlo iteration. See the the \code{bdpsurvival} vignette \cr
 #'   \code{vignette("bdpsurvival-vignette", package="bayesDP")} for more details.
+#' @param compare logical. Should a comparison object be included in the fit?
+#'   For a one-arm analysis, the comparison object is simply the posterior
+#'   chain of the treatment group parameter. For a two-arm analysis, the comparison
+#'   object is the posterior chain of the treatment effect that compares treatment and
+#'   control. If \code{compare=TRUE}, the comparison object is accessible in the
+#'   \code{final} slot, else the \code{final} slot is \code{NULL}. Default is
+#'   \code{TRUE}.
 #' @details \code{bdpsurvival} uses a two-stage approach for determining the
 #'   strength of historical data in estimation of a survival probability outcome.
 #'   In the first stage, a Weibull distribution function is used as a
@@ -131,6 +142,16 @@
 #'  \item{\code{posterior_control}}{
 #'    list. If two-arm trial, contains values related to the control group
 #'    analagous to the \code{posterior_treatment} output.}
+#'
+#'  \item{\code{final}}{
+#'    list. Contains the final comparison object, dependent on the analysis type:}
+#'    \itemize{
+#'      \item{One-arm analysis:}{
+#'        vector. Posterior chain of survival probability at requested time.}
+#'      \item{Two-arm analysis:}{
+#'        vector. Posterior chain of log-hazard rate comparing treatment and control groups.}
+#'   }
+#'
 #'  \item{\code{args1}}{
 #'    list. Entries contain user inputs. In addition, the following elements
 #'    are ouput:}
@@ -206,45 +227,48 @@
 #'
 #' @rdname bdpsurvival
 #' @import methods
-#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov pchisq
+#' @importFrom stats sd density is.empty.model median model.offset model.response pweibull quantile rbeta rgamma rnorm var vcov
 #' @importFrom survival Surv survSplit
 #' @aliases bdpsurvival,ANY-method
 #' @export bdpsurvival
 bdpsurvival <- setClass("bdpsurvival", slots = c(posterior_treatment = "list",
                                                  posterior_control = "list",
+                                                 final = "list",
                                                  args1 = "list"))
 setGeneric("bdpsurvival",
-  function(formula       = formula,
-           data          = data,
-           breaks        = NULL,
-           a0            = 0.1,
-           b0            = 0.1,
-           surv_time     = NULL,
-           alpha_max     = 1,
-           fix_alpha     = FALSE,
-           number_mcmc   = 10000,
-           weibull_scale = 0.135,
-           weibull_shape = 3,
-           two_side      = TRUE,
-           method        = "fixed"){
+  function(formula           = formula,
+           data              = data,
+           breaks            = NULL,
+           a0                = 0.1,
+           b0                = 0.1,
+           surv_time         = NULL,
+           discount_function = "weibull",
+           alpha_max         = 1,
+           fix_alpha         = FALSE,
+           number_mcmc       = 10000,
+           weibull_scale     = 0.135,
+           weibull_shape     = 3,
+           method            = "fixed",
+           compare           = TRUE){
              standardGeneric("bdpsurvival")
            })
 
 setMethod("bdpsurvival",
   signature(),
-  function(formula       = formula,
-           data          = data,
-           breaks        = NULL,
-           a0            = 0.1,
-           b0            = 0.1,
-           surv_time     = NULL,
-           alpha_max     = 1,
-           fix_alpha     = FALSE,
-           number_mcmc   = 10000,
-           weibull_scale = 0.135,
-           weibull_shape = 3,
-           two_side      = TRUE,
-           method        = "fixed"){
+  function(formula           = formula,
+           data              = data,
+           breaks            = NULL,
+           a0                = 0.1,
+           b0                = 0.1,
+           surv_time         = NULL,
+           discount_function = "weibull",
+           alpha_max         = 1,
+           fix_alpha         = FALSE,
+           number_mcmc       = 10000,
+           weibull_scale     = 0.135,
+           weibull_shape     = 3,
+           method            = "fixed",
+           compare           = TRUE){
 
   ### Check data frame and ensure it has the correct column names
   namesData <- tolower(names(data))
@@ -265,9 +289,18 @@ setMethod("bdpsurvival",
   }
 
 
+  # Check that discount_function is input correctly
+  all_functions <- c("weibull", "scaledweibull", "identity")
+  function_match <- match(discount_function, all_functions)
+  if(is.na(function_match)) {
+    stop("discount_function input incorrectly.")
+  }
+
+
   historical <- NULL
   treatment <- NULL
 
+
   ##############################################################################
   # Quick check, if alpha_max, weibull_scale, or weibull_shape have length 1,
   # repeat input twice
@@ -355,62 +388,83 @@ setMethod("bdpsurvival",
   }
 
   posterior_treatment <- posterior_survival(
-    S             = S_t,
-    S0            = S0_t,
-    surv_time     = surv_time,
-    alpha_max     = alpha_max[1],
-    fix_alpha     = fix_alpha,
-    a0            = a0,
-    b0            = b0,
-    number_mcmc   = number_mcmc,
-    weibull_shape = weibull_shape[1],
-    weibull_scale = weibull_scale[1],
-    two_side      = two_side,
-    breaks        = breaks,
-    arm2          = arm2,
-    method        = method)
+    S                 = S_t,
+    S0                = S0_t,
+    surv_time         = surv_time,
+    discount_function = discount_function,
+    alpha_max         = alpha_max[1],
+    fix_alpha         = fix_alpha,
+    a0                = a0,
+    b0                = b0,
+    number_mcmc       = number_mcmc,
+    weibull_shape     = weibull_shape[1],
+    weibull_scale     = weibull_scale[1],
+    breaks            = breaks,
+    arm2              = arm2,
+    method            = method)
 
   if(arm2){
     posterior_control <- posterior_survival(
-      S             = S_c,
-      S0            = S0_c,
-      alpha_max     = alpha_max[2],
-      fix_alpha     = fix_alpha,
-      a0            = a0,
-      b0            = b0,
-      surv_time     = surv_time,
-      number_mcmc   = number_mcmc,
-      weibull_shape = weibull_shape[2],
-      weibull_scale = weibull_scale[2],
-      two_side      = two_side,
-      breaks        = breaks,
-      arm2          = arm2,
-      method        = method)
+      S                 = S_c,
+      S0                = S0_c,
+      discount_function = discount_function,
+      alpha_max         = alpha_max[2],
+      fix_alpha         = fix_alpha,
+      a0                = a0,
+      b0                = b0,
+      surv_time         = surv_time,
+      number_mcmc       = number_mcmc,
+      weibull_shape     = weibull_shape[2],
+      weibull_scale     = weibull_scale[2],
+      breaks            = breaks,
+      arm2              = arm2,
+      method            = method)
   } else{
     posterior_control <- NULL
   }
 
 
-  args1 <- list(S_t           = S_t,
-                S_c           = S_c,
-                S0_t          = S0_t,
-                S0_c          = S0_c,
-                alpha_max     = alpha_max,
-                fix_alpha     = fix_alpha,
-                a0            = a0,
-                b0            = b0,
-                surv_time     = surv_time,
-                number_mcmc   = number_mcmc,
-                weibull_scale = weibull_scale,
-                weibull_shape = weibull_shape,
-                two_side      = two_side,
-                method        = method,
-                arm2          = arm2,
-                breaks        = breaks,
-                data          = data)
+  args1 <- list(S_t               = S_t,
+                S_c               = S_c,
+                S0_t              = S0_t,
+                S0_c              = S0_c,
+                discount_function = discount_function,
+                alpha_max         = alpha_max,
+                fix_alpha         = fix_alpha,
+                a0                = a0,
+                b0                = b0,
+                surv_time         = surv_time,
+                number_mcmc       = number_mcmc,
+                weibull_scale     = weibull_scale,
+                weibull_shape     = weibull_shape,
+                method            = method,
+                arm2              = arm2,
+                breaks            = breaks,
+                data              = data)
+
+
+  ##############################################################################
+  ### Create final (comparison) object
+  ##############################################################################
+  if(!compare){
+    final <- NULL
+  } else{
+    if(arm2){
+      R0      <- log(posterior_treatment$posterior_hazard)-log(posterior_control$posterior_hazard)
+      V0      <- 1/apply(R0,2,var)
+      logHR0  <- R0%*%V0/sum(V0)
+      final   <- list()
+      final$posterior_loghazard <- logHR0
+    } else{
+      final                    <- list()
+      final$posterior_survival <- posterior_treatment$posterior_survival
+    }
+  }
+
 
   me <- list(posterior_treatment = posterior_treatment,
              posterior_control   = posterior_control,
+             final               = final,
              args1               = args1)
 
   class(me) <- "bdpsurvival"
@@ -427,9 +481,10 @@ setMethod("bdpsurvival",
 # 2) Estimate the posterior of the augmented data
 ################################################################################
 ### Combine  loss function and posterior estimation into one function
-posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
+posterior_survival <- function(S, S0, surv_time, discount_function,
+                               alpha_max, fix_alpha, a0, b0,
                                number_mcmc, weibull_shape, weibull_scale,
-                               two_side, breaks, arm2, method){
+                               breaks, arm2, method){
 
 
   ### Extract intervals and count number of intervals
@@ -564,8 +619,8 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
 
       v          <- as.matrix(posterior_flat_hazard[,1:nIntervals]^2) %*% (surv_times^2/a_post[1:nIntervals])
       v0         <- as.matrix(prior_hazard[,1:nIntervals]^2) %*% (surv_times^2/a_post0[1:nIntervals])
-      Z          <- (logS - logS0)^2 / (v+v0)
-      p_hat      <- pchisq(Z, df=1, lower.tail=FALSE)
+      Z          <- abs(logS - logS0) / (v+v0)
+      p_hat      <- 2*(1-pnorm(Z))
 
     } else if(method == "fixed"){
       p_hat <- mean(posterior_flat_survival > prior_survival)   # higher is better survival
@@ -576,12 +631,20 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
     if(fix_alpha){
       alpha_discount <- alpha_max
     } else{
-      if (!two_side | method == "mc") {
-        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
-      } else if (two_side){
-        p_hat    <- ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
-        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
-      }
+        p_hat          <- 2*ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
+
+        # Compute alpha discount based on distribution
+        if(discount_function == "weibull"){
+          alpha_discount <- pweibull(p_hat, shape=weibull_shape,
+                                     scale=weibull_scale)*alpha_max
+        } else if(discount_function == "scaledweibull"){
+          max_p <- pweibull(1, shape=weibull_shape, scale=weibull_scale)
+
+          alpha_discount <- pweibull(p_hat, shape=weibull_shape,
+                                     scale=weibull_scale)*alpha_max/max_p
+        } else if(discount_function == "identity"){
+          alpha_discount <- p_hat
+        }
     }
   } else{
     ### Weight historical data via (approximate) hazard ratio comparing
@@ -592,13 +655,13 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
       v0    <- 1/(a_post0)
       R     <- rowSums(as.matrix(R0/(v+v0) / sum(1/(v+v0))))
       V0    <- 1 / sum(1/(v+v0))
-      Z     <- R^2 / V0
-      p_hat <- pchisq(Z, df=1, lower.tail=FALSE)
+      Z     <- abs(R) / V0
+      p_hat <- 2*(1-pnorm(Z))
     } else if(method == "fixed"){
       R0     <- log(prior_hazard)-log(posterior_flat_hazard)
       V0     <- 1/apply(R0,2,var)
       logHR0 <- R0%*%V0/sum(V0)    #weighted average  of SE^2
-      p_hat <- mean(logHR0 > 0)    #larger is higher failure
+      p_hat  <- mean(logHR0 > 0)   #larger is higher failure
     } else{
       stop("Unrecognized method. Use one of 'fixed' or 'mc'")
     }
@@ -606,12 +669,20 @@ posterior_survival <- function(S, S0, surv_time, alpha_max, fix_alpha, a0, b0,
     if(fix_alpha){
       alpha_discount <- alpha_max
     } else{
-      if (!two_side | method == "mc") {
-        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
-      } else if (two_side){
-        p_hat    <- ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
-        alpha_discount <- pweibull(p_hat, shape=weibull_shape, scale=weibull_scale)*alpha_max
-      }
+        p_hat    <- 2*ifelse(p_hat > 0.5, 1 - p_hat, p_hat)
+
+        # Compute alpha discount based on distribution
+        if(discount_function == "weibull"){
+          alpha_discount <- pweibull(p_hat, shape=weibull_shape,
+                                     scale=weibull_scale)*alpha_max
+        } else if(discount_function == "scaledweibull"){
+          max_p <- pweibull(1, shape=weibull_shape, scale=weibull_scale)
+
+          alpha_discount <- pweibull(p_hat, shape=weibull_shape,
+                                     scale=weibull_scale)*alpha_max/max_p
+        } else if(discount_function == "identity"){
+          alpha_discount <- p_hat
+        }
     }
   }
 
