@@ -15,15 +15,21 @@ opts_chunk$set(
   )
 
 # Run two models to document the discount function plots
-fit01 <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250, two_side=FALSE)
+fit01 <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250)
 fit02 <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250)
 
+fit_scaledweibull <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250, 
+                                 discount_function="scaledweibull")
+fit_identity <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250,
+                            discount_function="identity")
 
 ## ---- echo=FALSE---------------------------------------------------------
-plot(fit02, type="discount")
+df1 <- plot(fit02, type="discount", print=FALSE)
+df1 + ggtitle("Discount function plot", "Weibull distribution with shape=3 and scale=0.135")
 
 ## ---- echo=FALSE---------------------------------------------------------
-plot(fit01, type="discount")
+df2 <- plot(fit_identity, type="discount", print=FALSE)
+df2 + ggtitle("Discount function plot", "Identity")
 
 ## ------------------------------------------------------------------------
 p1 <- plot(fit01, type="discount", print=FALSE)
