@@ -25,16 +25,23 @@ example_surv_1arm <- data.frame(status     = status,
 
 fit01 <- bdpsurvival(Surv(time, status) ~ historical + treatment,
                      data = example_surv_1arm,
-                     surv_time = 5, two_side=FALSE)
+                     surv_time = 5)
 fit02 <- bdpsurvival(Surv(time, status) ~ historical + treatment,
                      data = example_surv_1arm,
                      surv_time = 5)
 
-## ---- echo=FALSE---------------------------------------------------------
-plot(fit02, type="discount")
+fit_scaledweibull <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250, 
+                                 discount_function="scaledweibull")
+fit_identity <- bdpbinomial(y_t=10, N_t=500, y0_t=25, N0_t=250,
+                            discount_function="identity")
 
 ## ---- echo=FALSE---------------------------------------------------------
-plot(fit01, type="discount")
+df1 <- plot(fit02, type="discount", print=FALSE)
+df1 + ggtitle("Discount function plot", "Weibull distribution with shape=3 and scale=0.135")
+
+## ---- echo=FALSE---------------------------------------------------------
+df2 <- plot(fit_identity, type="discount", print=FALSE)
+df2 + ggtitle("Discount function plot", "Identity")
 
 ## ------------------------------------------------------------------------
 p1 <- plot(fit01, type="discount", print=FALSE)
